==> ejc-sddjsorg-api-3.0.0-20211013.093409-9-sources.jar: com/ejianc/business/sddjsorg/vo/OrgApplyFileSetVO.java <==
package com.ejianc.business.sddjsorg.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 组织机构申请-资料设置
 * 
 * @author generator
 * 
 */
public class OrgApplyFileSetVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.String name; // 档案资料名称
    private java.lang.Integer required; // 是否必须上传
    private java.lang.String memo; // 备注
    private java.lang.Integer inUse; // 是否启用
    private java.lang.String type; // 类型：set:设立申请，change：变更，del：注销，merge：合并，divide：分立，supplementary:补录
    

    /**
     * 档案资料名称
     */
    public java.lang.String getName() {
        return name;
    }

    /**
     * 档案资料名称
     */
    public void setName(java.lang.String name) {
        this.name = name;
    }
    /**
     * 是否必须上传
     */
    public java.lang.Integer getRequired() {
        return required;
    }

    /**
     * 是否必须上传
     */
    public void setRequired(java.lang.Integer required) {
        this.required = required;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    /**
     * 是否启用
     */
    public java.lang.Integer getInUse() {
        return inUse;
    }

    /**
     * 是否启用
     */
    public void setInUse(java.lang.Integer inUse) {
        this.inUse = inUse;
    }
    /**
     * 类型：set:设立申请，change：变更，del：注销，merge：合并，divide：分立，supplementary:补录
     */
    public java.lang.String getType() {
        return type;
    }

    /**
     * 类型：set:设立申请，change：变更，del：注销，merge：合并，divide：分立，supplementary:补录
     */
    public void setType(java.lang.String type) {
        this.type = type;
    }
    
}

==> ejc-sddjsorg-api-3.0.0-20211015.112102-15-sources.jar: com/ejianc/business/sddjsorg/vo/OrgApplyFileSetVO.java <==
package com.ejianc.business.sddjsorg.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 组织机构申请-资料设置
 * 
 * @author generator
 * 
 */
public class OrgApplyFileSetVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.String name; // 档案资料名称
    private Boolean required; // 是否必须上传
    private java.lang.String memo; // 备注
    private Boolean inUse; // 是否启用
    private java.lang.String type; // 类型：set:设立申请，change：变更，del：注销，merge：合并，divide：分立，supplementary:补录
    

    /**
     * 档案资料名称
     */
    public java.lang.String getName() {
        return name;
    }

    /**
     * 档案资料名称
     */
    public void setName(java.lang.String name) {
        this.name = name;
    }
    /**
     * 是否必须上传
     */
    public Boolean getRequired() {
        return required;
    }

    public void setRequired(Boolean required) {
        this.required = required;
    }

    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    /**
     * 是否启用
     */
    public Boolean getInUse() {
        return inUse;
    }

    public void setInUse(Boolean inUse) {
        this.inUse = inUse;
    }

    /**
     * 类型：set:设立申请，change：变更，del：注销，merge：合并，divide：分立，supplementary:补录
     */
    public java.lang.String getType() {
        return type;
    }

    /**
     * 类型：set:设立申请，change：变更，del：注销，merge：合并，divide：分立，supplementary:补录
     */
    public void setType(java.lang.String type) {
        this.type = type;
    }
    
}
